@@ -11,22 +11,27 @@ from .constraint import Constraint
 
 
 class PlaneConstraint(Constraint):
-
     def __init__(self, plane, **kwargs):
         super(PlaneConstraint, self).__init__(geometry=plane, **kwargs)
 
     @property
     def data(self):
-        return {'geometry': self.geometry.data}
+        return {
+            "geometry": self.geometry.data,
+            "rhino_guid": str(self._rhino_guid),
+        }
 
     @data.setter
     def data(self, data):
-        self.geometry = Plane.from_data(data['geometry'])
+        self.geometry = Plane.from_data(data["geometry"])
+        self._rhino_guid = str(data["rhino_guid"])
 
     @classmethod
     def from_data(cls, data):
-        plane = Plane.from_data(data['geometry'])
-        return cls(plane)
+        plane = Plane.from_data(data["geometry"])
+        constraint = cls(plane)
+        constraint._rhino_guid = str(data["rhino_guid"])
+        return constraint
 
     def compute_tangent(self):
         self._tangent = self.residual - self.normal
