@@ -8,25 +8,30 @@ from .constraint import Constraint
 
 
 class VectorConstraint(Constraint):
-
     def __init__(self, vector, **kwargs):
         super(VectorConstraint, self).__init__(geometry=vector, **kwargs)
 
     @property
     def data(self):
-        return {'geometry': self.geometry.data}
+        return {
+            "geometry": self.geometry.data,
+            "rhino_guid": str(self._rhino_guid),
+        }
 
     @data.setter
     def data(self, data):
-        self.geometry = Vector.from_data(data['geometry'])
+        self.geometry = Vector.from_data(data["geometry"])
+        self._rhino_guid = str(data["rhino_guid"])
 
     @classmethod
     def from_data(cls, data):
-        vector = Vector.from_data(data['geometry']).unitized()
-        return cls(vector)
+        vector = Vector.from_data(data["geometry"]).unitized()
+        constraint = cls(vector)
+        constraint._rhino_guid = str(data["rhino_guid"])
+        return constraint
 
     def compute_tangent(self):
-        self._tangent = Vector(* vector_component(self.residual, self.geometry))
+        self._tangent = Vector(*vector_component(self.residual, self.geometry))
 
     def compute_normal(self):
         self._normal = self.residual - self.tangent
