@@ -26,6 +26,9 @@ from .fd_numpy import fd_numpy
 from .fd_constrained_numpy import fd_constrained_numpy
 from .mesh_fd_numpy import mesh_fd_numpy
 from .mesh_fd_constrained_numpy import mesh_fd_constrained_numpy
+from .mesh_fd_constrained_cache import mesh_fd_constrained_cache_call  # noqa: F401
+from .mesh_fd_constrained_cache import mesh_fd_constrained_cache_create  # noqa: F401
+from .mesh_fd_constrained_cache import mesh_fd_constrained_cache_delete  # noqa: F401
 
 __all__ = [
     "fd_numpy",
