@@ -2,12 +2,11 @@ from typing import List
 from typing import NamedTuple
 from typing_extensions import Literal
 from nptyping import NDArray
-
-import numpy as np
+from nptyping import Float64
 
 
 class Result(NamedTuple):
-    vertices: NDArray[Literal["N", 3], np.float64]
-    residuals: NDArray[Literal["N", 3], np.float64]
+    vertices: NDArray[Literal["*, 3"], Float64]
+    residuals: NDArray[Literal["*, 3"], Float64]
     forces: List[float]
     lenghts: List[float]
