@@ -1,11 +1,10 @@
 """
-******************
-compas_fd.loads
-******************
+***************
+loads
+***************
 
 .. currentmodule:: compas_fd.loads
 
-
 Classes
 =======
 
@@ -20,12 +19,6 @@ from __future__ import print_function
 from __future__ import absolute_import
 from __future__ import division
 
-import compas
+from .selfweight import SelfweightCalculator
 
-if not compas.IPY:
-    from .selfweight import SelfweightCalculator
-
-__all__ = []
-
-if not compas.IPY:
-    __all__ += ['SelfweightCalculator']
+__all__ = ["SelfweightCalculator"]
